==> milkviz-0.3.2.tar.gz: milkviz-0.3.2/README.md <==
# MilkViz

[![Documentation Status](https://img.shields.io/readthedocs/milkviz?logo=readthedocs&logoColor=white&style=flat-square)](https://milkviz.readthedocs.io/en/latest?badge=latest)
![Build&Test](https://img.shields.io/github/workflow/status/Mr-Milk/milkviz/Build?style=flat-square&logo=github)
![pypi version](https://img.shields.io/pypi/v/milkviz?color=blue&logo=python&logoColor=white&style=flat-square)

Mr-Milk's own visualization library. 
Some commonly used visualizations in my own research.
But not available out there.

[Gallery](https://milkviz.readthedocs.io/en/latest/gallery_examples/index.html)

<p>
<table>
<tr>

  <td align="center">
    
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="point_map" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_point_map_cat_thumb.png" height="60" width="80"/>
    <p >Point map</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_stacked_bar.html">
  <img alt="stacked_bar" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_stacked_bar_thumb.png" height="60" width="80"/>
<p>Stacked bar</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="bubble_plot" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_bubble_thumb.png" height="60" width="80"/>
<p>Bubble</p>  
</a>
  </td>

</tr>
<tr>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="dot_heatmp" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_dot_heatmap_thumb.png" height="60" width="80"/>
<p>Dot heatmap</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_dot_heatmap_matrix_masked.html">
  <img alt="dot_heatmap_matrix" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_dot_heatmap_matrix_masked_thumb.png" height="60" width="80"/>
<p>Masked dot heatmap</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_dot_heatmap_matrix_masked.html">
  <img alt="heatmap" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_anno_heatmap_thumb.png" height="60" width="80"/>
<p>Annotated clustermap</p>    
</a>
  </td>

</tr>

<tr>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_venn.html">
  <img alt="venn" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_venn_thumb.png" height="60" width="80"/>
<p>Venn</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_upset.html">
  <img alt="upsetplot" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_upset_thumb.png" height="60" width="80"/>
<p>Upsetplot</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_graph.html">
  <img alt="graph" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_graph_thumb.png" height="60" width="80"/>
<p>Graph</p>    
</a>
  </td>

</tr>
</table>
</p>

Copyright © 2021, Mr-Milk

==> milkviz-0.5.3.tar.gz: milkviz-0.5.3/README.md <==
# MilkViz

[![Documentation Status](https://img.shields.io/readthedocs/milkviz?logo=readthedocs&logoColor=white&style=flat-square)](https://milkviz.readthedocs.io/en/latest?badge=latest)
![Build&Test](https://img.shields.io/github/workflow/status/Mr-Milk/milkviz/Build?style=flat-square&logo=github)
![pypi version](https://img.shields.io/pypi/v/milkviz?color=blue&logo=python&logoColor=white&style=flat-square)

Mr-Milk's own visualization library. 
Some commonly used visualizations in my own research.
But not available out there.

[Gallery](https://milkviz.readthedocs.io/en/latest/gallery_examples/index.html)

<p>
<table>
<tr>

  <td align="center">
    
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="point_map" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_point_map_value_thumb.png" height="60" width="80"/>
    <p >Point map</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_stacked_bar.html">
  <img alt="stacked_bar" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_stacked_bar_thumb.png" height="65" width="80"/>
<p>Stacked bar</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="bubble_plot" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_bubble_thumb.png" height="60" width="80"/>
<p>Bubble</p>  
</a>
  </td>

</tr>
<tr>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_point_map_cat.html">
  <img alt="dot_heatmp" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_dot_heatmap_thumb.png" height="60" width="80"/>
<p>Dot heatmap</p>  
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_dot_heatmap_matrix_masked.html">
  <img alt="dot_heatmap_matrix" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_dot_heatmap_matrix_masked_thumb.png" height="60" width="80"/>
<p>Masked dot heatmap</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_dot_heatmap_matrix_masked.html">
  <img alt="heatmap" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_anno_heatmap_thumb.png" height="60" width="80"/>
<p>Annotated clustermap</p>    
</a>
  </td>

</tr>

<tr>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_venn.html">
  <img alt="venn" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_venn_thumb.png" height="60" width="80"/>
<p>Venn</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_upset.html">
  <img alt="upsetplot" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_upset_thumb.png" height="60" width="80"/>
<p>Upsetplot</p>    
</a>
  </td>

  <td align="center">
  <a href="https://milkviz.readthedocs.io/en/latest/gallery_examples/plot_graph.html">
  <img alt="graph" src="https://milkviz.readthedocs.io/en/latest/_images/sphx_glr_plot_graph_thumb.png" height="60" width="80"/>
<p>Graph</p>    
</a>
  </td>

</tr>
</table>
</p>

Copyright © 2021, Mr-Milk
